@@ -33,7 +33,16 @@ class AlbArnTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.AlbArnTarget",
 ):
-    '''A single Application Load Balancer as the target for load balancing.'''
+    '''A single Application Load Balancer as the target for load balancing.
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        alb_arn_target = elasticloadbalancingv2_targets.AlbArnTarget("albArn", 123)
+    '''
 
     def __init__(self, alb_arn: builtins.str, port: jsii.Number) -> None:
         '''Create a new alb target.
@@ -63,7 +72,44 @@ class AlbTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.AlbTarget",
 ):
-    '''A single Application Load Balancer as the target for load balancing.'''
+    '''A single Application Load Balancer as the target for load balancing.
+
+    Example::
+
+        import aws_cdk.aws_elasticloadbalancingv2_targets as targets
+        import aws_cdk.aws_ecs as ecs
+        import aws_cdk.aws_ecs_patterns as patterns
+        
+        # vpc is of type Vpc
+        
+        
+        task = ecs.FargateTaskDefinition(self, "Task", cpu=256, memory_limit_mi_b=512)
+        task.add_container("nginx",
+            image=ecs.ContainerImage.from_registry("public.ecr.aws/nginx/nginx:latest"),
+            port_mappings=[ecs.PortMapping(container_port=80)]
+        )
+        
+        svc = patterns.ApplicationLoadBalancedFargateService(self, "Service",
+            vpc=vpc,
+            task_definition=task,
+            public_load_balancer=False
+        )
+        
+        nlb = elbv2.NetworkLoadBalancer(self, "Nlb",
+            vpc=vpc,
+            cross_zone_enabled=True,
+            internet_facing=True
+        )
+        
+        listener = nlb.add_listener("listener", port=80)
+        
+        listener.add_targets("Targets",
+            targets=[targets.AlbTarget(svc.load_balancer, 80)],
+            port=80
+        )
+        
+        CfnOutput(self, "NlbEndpoint", value=f"http://{nlb.loadBalancerDnsName}")
+    '''
 
     def __init__(
         self,
@@ -86,6 +132,14 @@ class InstanceIdTarget(
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can connect to the instance.
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        instance_id_target = elasticloadbalancingv2_targets.InstanceIdTarget("instanceId", 123)
     '''
 
     def __init__(
@@ -134,6 +188,19 @@ class InstanceTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.InstanceTarget",
 ):
+    '''
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_ec2 as ec2
+        import aws_cdk.aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        # instance is of type Instance
+        
+        instance_target = elasticloadbalancingv2_targets.InstanceTarget(instance, 123)
+    '''
+
     def __init__(
         self,
         instance: aws_cdk.aws_ec2.Instance,
@@ -161,6 +228,14 @@ class IpTarget(
 
     If you register a target of this type, you are responsible for making
     sure the load balancer's security group can send packets to the IP address.
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_elasticloadbalancingv2_targets as elasticloadbalancingv2_targets
+        
+        ip_target = elasticloadbalancingv2_targets.IpTarget("ipAddress", 123, "availabilityZone")
     '''
 
     def __init__(
@@ -226,6 +301,28 @@ class LambdaTarget(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-targets.LambdaTarget",
 ):
+    '''
+    Example::
+
+        import aws_cdk.aws_lambda as lambda_
+        import aws_cdk.aws_elasticloadbalancingv2_targets as targets
+        
+        # lambda_function is of type Function
+        # lb is of type ApplicationLoadBalancer
+        
+        
+        listener = lb.add_listener("Listener", port=80)
+        listener.add_targets("Targets",
+            targets=[targets.LambdaTarget(lambda_function)],
+        
+            # For Lambda Targets, you need to explicitly enable health checks if you
+            # want them.
+            health_check=elbv2.HealthCheck(
+                enabled=True
+            )
+        )
+    '''
+
     def __init__(self, fn: aws_cdk.aws_lambda.IFunction) -> None:
         '''Create a new Lambda target.
 
